# PESummary

[![Coverage report](https://docs.ligo.org/charlie.hoy/pesummary/coverage_badge.svg)](https://docs.ligo.org/charlie.hoy/pesummary/htmlcov/index.html)

This package helps the user to generate summary webpages to visualise the output from both LALInference and Bilby.

 * [Installation instructions](https://docs.ligo.org/charlie.hoy/pesummary/installation.html)
 * [Documentation](https://docs.ligo.org/charlie.hoy/pesummary)
 * [Issue Tracker](https://git.ligo.org/charlie.hoy/pesummary/issues)
